<?php

namespace App\Model;

use App\Gateway\TeamGateway;
use App\Data\Team;
use App\Data\Member;
use App\Data\MemberRole;
use http\Url;

/**
 *
 */
class TeamModel /* throw des exceptions(ex validation des champs, filtre etc) pour le controller qui l'utilise, catch celle de la gw,  */
{
    private TeamGateway $gateway;

    /**
     * @param TeamGateway $gateway
     */
    public function __construct(TeamGateway $gateway) {
        $this->gateway = $gateway;
    }

    public function createTeam(string $name, string $picture, int $mainColor, int $secondColor): int{
        $this->gateway->insert($name, $picture, $mainColor, $secondColor);
        $result = $this->gateway->getIdTeamByName($name);
        return intval($result[0]['id']);
    }

    public function listByName(string $name): array {
        $teams = [];
        $results = $this->gateway->listByName($name);
        foreach ($results as $row) {
            $url = new Url($row['picture']);
            $teams[] = new Team($row['id'], $row['name'], $url, $row['mainColor'], $row['secondColor']);
        }
        return $teams;
    }

    public function displayTeam(int $id): Team {
        $members = [];
        $result = $this->gateway->getTeamById($id);
        $resultMembers = $this->gateway->getMembersById($id);
        foreach ($resultMembers as $row) {
            if ($row['role'] == 'C') {
                $role = MemberRole::coach();
            } else {
                $role = MemberRole::player();
            }
            $members[] = new Member($row['id'], $role);
        }
        return new Team($result['id'], $result['name'], $result['picture'], $result['mainColor'], $result['secondColor'], $members);
    }

}